==> tayuya-0.0.1-py3-none-any.whl: tayuya/constants.py <==
# Standard tuning of each string
GUITAR_STAFF: dict = {0: 'E', 1: 'A', 2: 'D', 3: 'G', 4: 'B', 5: 'E'}
UKULELE_STAFF: dict = {0: 'G', 1: 'C', 2: 'E', 3: 'A'}

# Number of strings
GUITAR_STRING = 6
UKULELE_STRING = 4

# MIDI value to notes
MIDI_TO_NOTES = {
    0: [''],
    1: [''],
    10: [''],
    100: ['E7'],
    101: ['F7'],
    102: ['F#7', 'Gb7'],
    103: ['G7'],
    104: ['G#7', 'Ab7'],
    105: ['A7'],
    106: ['A#7', 'Bb7'],
    107: ['B7'],
    108: ['C8'],
    109: ['C#8', 'Db8'],
    11: [''],
    110: ['D8'],
    111: ['D#8', 'Eb8'],
    112: ['E8'],
    113: ['F8'],
    114: ['F#8', 'Gb8'],
    115: ['G8'],
    116: ['G#8', 'Ab8'],
    117: ['A8'],
    118: ['A#8', 'Bb8'],
    119: ['B8'],
    12: [''],
    120: ['C9'],
    121: ['C#9', 'Db9'],
    122: ['D9'],
    123: ['D#9', 'Eb9'],
    124: ['E9'],
    125: ['F9'],
    126: ['F#9', 'Gb9'],
    127: ['G9'],
    13: [''],
    14: [''],
    15: [''],
    16: [''],
    17: [''],
    18: [''],
    19: [''],
    2: [''],
    20: [''],
    21: ['A0'],
    22: ['A#0', 'Bb0'],
    23: ['B0'],
    24: ['C1'],
    25: ['C#1', 'Db1'],
    26: ['D1'],
    27: ['D#1', 'Eb1'],
    28: ['E1'],
    29: ['F1'],
    3: [''],
    30: ['F#1', 'Gb1'],
    31: ['G1'],
    32: ['G#1', 'Ab1'],
    33: ['A1'],
    34: ['A#1', 'Bb1'],
    35: ['B1'],
    36: ['C2'],
    37: ['C#2', 'Db2'],
    38: ['D2'],
    39: ['D#2', 'Eb2'],
    4: [''],
    40: ['E2'],
    41: ['F2'],
    42: ['F#2', 'Gb2'],
    43: ['G2'],
    44: ['G#2', 'Ab2'],
    45: ['A2'],
    46: ['A#2', 'Bb2'],
    47: ['B2'],
    48: ['C3'],
    49: ['C#3', 'Db3'],
    5: [''],
    50: ['D3'],
    51: ['D#3', 'Eb3'],
    52: ['E3'],
    53: ['F3'],
    54: ['F#3', 'Gb3'],
    55: ['G3'],
    56: ['G#3', 'Ab3'],
    57: ['A3'],
    58: ['A#3', 'Bb3'],
    59: ['B3'],
    6: [''],
    60: ['C4'],
    61: ['C#4', 'Db4'],
    62: ['D4'],
    63: ['D#4', 'Eb4'],
    64: ['E4'],
    65: ['F4'],
    66: ['F#4', 'Gb4'],
    67: ['G4'],
    68: ['G#4', 'Ab4'],
    69: ['A4'],
    7: [''],
    70: ['A#4', 'Bb4'],
    71: ['B4'],
    72: ['C5'],
    73: ['C#5', 'Db5'],
    74: ['D5'],
    75: ['D#5', 'Eb5'],
    76: ['E5'],
    77: ['F5'],
    78: ['F#5', 'Gb5'],
    79: ['G5'],
    8: [''],
    80: ['G#5', 'Ab5'],
    81: ['A5'],
    82: ['A#5', 'Bb5'],
    83: ['B5'],
    84: ['C6'],
    85: ['C#6', 'Db6'],
    86: ['D6'],
    87: ['D#6', 'Eb6'],
    88: ['E6'],
    89: ['F6'],
    9: [''],
    90: ['F#6', 'Gb6'],
    91: ['G6'],
    92: ['G#6', 'Ab6'],
    93: ['A6'],
    94: ['A#6', 'Bb6'],
    95: ['B6'],
    96: ['C7'],
    97: ['C#7', 'Db7'],
    98: ['D7'],
    99: ['D#7', 'Eb7']
}

# MIDI metadata
TIME_SIGNATURE = 'time_signature'
NOTE_ON = 'note_on'
NOTE_OFF = 'note_off'
HALF_NOTE = 'half'
WHOLE_NOTE = 'whole'
QUARTER_NOTE = 'quarter'
EIGHTH_NOTE = 'eighth'
SIXTEENTH_NOTE = 'sixteenth'

NUM_TO_NOTES = {1: WHOLE_NOTE, 2: HALF_NOTE, 4: QUARTER_NOTE,
                8: EIGHTH_NOTE, 16: SIXTEENTH_NOTE}


FRET_NOTES = \
    [['F4', 'F#4', 'G4', 'Ab4', 'A4', 'Bb4', 'B4', 'C5', 'C#5', 'D5', 'Eb5', 'E5', 'F5', 'F#5', 'G5', 'Ab5', 'A5', 'Bb5', 'B5', 'C6', 'C#6', 'D6'],  # E
     ['C4', 'C#4', 'D4', 'Eb4', 'E4', 'F4', 'F#4', 'G4', 'Ab4', 'A4', 'Bb4', 'B4', 'C5', 'C#5', 'D5', 'Eb5', 'E5', 'F5', 'F#5', 'G5', 'Ab5', 'A5'],  # B
     ['Ab3', 'A3', 'Bb3', 'B3', 'C4', 'C#4', 'D4', 'Eb4', 'E4', 'F4', 'F#4', 'G4', 'Ab4', 'A4', 'Bb4', 'B4', 'C5', 'C#5', 'D5', 'Eb5', 'E5', 'F5'],  # G
     ['Eb3', 'E3', 'F3', 'F#3', 'G3', 'Ab3', 'A3', 'Bb3', 'B3', 'C4', 'C#4', 'D4', 'Eb4', 'E4', 'F4', 'F#4', 'G4', 'Ab4', 'A4', 'Bb4', 'B4', 'C5'],  # D
     ['Bb2', 'B2', 'C3', 'C#3', 'D3', 'Eb3', 'E3', 'F3', 'F#3', 'G3', 'Ab3', 'A3', 'Bb3', 'B3', 'C4', 'C#4', 'D4', 'Eb4', 'E4', 'F4', 'F#4', 'G4'],  # A
     ['F2', 'F#2', 'G2', 'Ab2', 'A2', 'Bb2', 'B2', 'C3', 'C#3', 'D3', 'Eb3', 'E3', 'F3', 'F#3', 'G3', 'Ab3', 'A3', 'Bb3', 'B3', 'C4', 'C#4', 'D4']]  # E
    #                3           5            7            9                  12                 15           17           19          21

TRACK_ERROR_MESSAGE = 'No track with string instrument found'


NOTE_TO_FRET = \
    {1: {'F4': 1,
      'F#4': 2,
      'G4': 3,
      'Ab4': 4,
      'G#4': 4,
      'A4': 5,
      'Bb4': 6,
      'A#4': 6,
      'B4': 7,
      'C5': 8,
      'C#5': 9,
      'D5': 10,
      'Eb5': 11,
      'D#5': 11,
      'E5': 12,
      'F5': 13,
      'F#5': 14,
      'G5': 15,
      'Ab5': 16,
      'G#5': 16,
      'A5': 17,
      'Bb5': 18,
      'A#5': 18,
      'B5': 19,
      'C6': 20,
      'C#6': 21,
      'D6': 22},
     2: {'C4': 1,
      'C#4': 2,
      'D4': 3,
      'Eb4': 4,
      'E4': 5,
      'F4': 6,
      'F#4': 7,
      'G4': 8,
      'Ab4': 9,
      'G#4': 9,
      'A4': 10,
      'Bb4': 11,
      'A#4': 11,
      'B4': 12,
      'C5': 13,
      'C#5': 14,
      'D5': 15,
      'Eb5': 16,
      'D#5': 16,
      'E5': 17,
      'F5': 18,
      'F#5': 19,
      'G5': 20,
      'Ab5': 21,
      'G#5': 21,
      'A5': 22},
     3: {'Ab3': 1,
      'G#3': 1,
      'A3': 2,
      'Bb3': 3,
      'A#3': 3,
      'B3': 4,
      'C4': 5,
      'C#4': 6,
      'D4': 7,
      'Eb4': 8,
      'E4': 9,
      'F4': 10,
      'F#4': 11,
      'G4': 12,
      'Ab4': 13,
      'G#4': 13,
      'A4': 14,
      'Bb4': 15,
      'A#4': 15,
      'B4': 16,
      'C5': 17,
      'C#5': 18,
      'D5': 19,
      'Eb5': 20,
      'D#5': 20,
      'E5': 21,
      'F5': 22},
     4: {'Eb3': 1,
      'D#3': 1,
      'E3': 2,
      'F3': 3,
      'F#3': 4,
      'G3': 5,
      'Ab3': 6,
      'G#3': 6,
      'A3': 7,
      'Bb3': 8,
      'A#3': 8,
      'B3': 9,
      'C4': 10,
      'C#4': 11,
      'D4': 12,
      'Eb4': 13,
      'E4': 14,
      'F4': 15,
      'F#4': 16,
      'G4': 17,
      'Ab4': 18,
      'G#4': 18,
      'A4': 19,
      'Bb4': 20,
      'A#4': 20,
      'B4': 21,
      'C5': 22},
     5: {'Bb2': 1,
      'A#2': 1,
      'B2': 2,
      'C3': 3,
      'C#3': 4,
      'D3': 5,
      'Eb3': 6,
      'D#3': 6,
      'E3': 7,
      'F3': 8,
      'F#3': 9,
      'G3': 10,
      'Ab3': 11,
      'G#3': 11,
      'A3': 12,
      'Bb3': 13,
      'A#3': 13,
      'B3': 14,
      'C4': 15,
      'C#4': 16,
      'D4': 17,
      'Eb4': 18,
      'E4': 19,
      'F4': 20,
      'F#4': 21,
      'G4': 22},
     6: {'F2': 1,
      'F#2': 2,
      'G2': 3,
      'Ab2': 4,
      'G#2': 4,
      'A2': 5,
      'Bb2': 6,
      'A#2': 6,
      'B2': 7,
      'C3': 8,
      'C#3': 9,
      'D3': 10,
      'Eb3': 11,
      'D#3': 11,
      'E3': 12,
      'F3': 13,
      'F#3': 14,
      'G3': 15,
      'Ab3': 16,
      'G#3': 16,
      'A3': 17,
      'Bb3': 18,
      'A#3': 18,
      'B3': 19,
      'C4': 20,
      'C#4': 21,
      'D4': 22}}


NOTE_TO_STRING =  \
    {'F4': {1: 1, 2: 6, 3: 10, 4: 15, 5: 20, 6: ''},
     'F#4': {1: 2, 2: 7, 3: 11, 4: 16, 5: 21, 6: ''},
     'G4': {1: 3, 2: 8, 3: 12, 4: 17, 5: 22, 6: ''},
     'Ab4': {1: 4, 2: 9, 3: 13, 4: 18, 5: '', 6: ''},
     'G#4': {1: 4, 2: 9, 3: 13, 4: 18, 5: '', 6: ''},
     'A4': {1: 5, 2: 10, 3: 14, 4: 19, 5: '', 6: ''},
     'Bb4': {1: 6, 2: 11, 3: 15, 4: 20, 5: '', 6: ''},
     'A#4': {1: 6, 2: 11, 3: 15, 4: 20, 5: '', 6: ''},
     'B4': {1: 7, 2: 12, 3: 16, 4: 21, 5: '', 6: ''},
     'C5': {1: 8, 2: 13, 3: 17, 4: 22, 5: '', 6: ''},
     'C#5': {1: 9, 2: 14, 3: 18, 4: '', 5: '', 6: ''},
     'D5': {1: 10, 2: 15, 3: 19, 4: '', 5: '', 6: ''},
     'Eb5': {1: 11, 2: 16, 3: 20, 4: '', 5: '', 6: ''},
     'D#5': {1: 11, 2: 16, 3: 20, 4: '', 5: '', 6: ''},
     'E5': {1: 12, 2: 17, 3: 21, 4: '', 5: '', 6: ''},
     'F5': {1: 13, 2: 18, 3: 22, 4: '', 5: '', 6: ''},
     'F#5': {1: 14, 2: 19, 3: '', 4: '', 5: '', 6: ''},
     'G5': {1: 15, 2: 20, 3: '', 4: '', 5: '', 6: ''},
     'Ab5': {1: 16, 2: 21, 3: '', 4: '', 5: '', 6: ''},
     'G#5': {1: 16, 2: 21, 3: '', 4: '', 5: '', 6: ''},
     'A5': {1: 17, 2: 22, 3: '', 4: '', 5: '', 6: ''},
     'Bb5': {1: 18, 2: '', 3: '', 4: '', 5: '', 6: ''},
     'A#5': {1: 18, 2: '', 3: '', 4: '', 5: '', 6: ''},
     'B5': {1: 19, 2: '', 3: '', 4: '', 5: '', 6: ''},
     'C6': {1: 20, 2: '', 3: '', 4: '', 5: '', 6: ''},
     'C#6': {1: 21, 2: '', 3: '', 4: '', 5: '', 6: ''},
     'D6': {1: 22, 2: '', 3: '', 4: '', 5: '', 6: ''},
     'C4': {1: '', 2: 1, 3: 5, 4: 10, 5: 15, 6: 20},
     'C#4': {1: '', 2: 2, 3: 6, 4: 11, 5: 16, 6: 21},
     'D4': {1: '', 2: 3, 3: 7, 4: 12, 5: 17, 6: 22},
     'Eb4': {1: '', 2: 4, 3: 8, 4: 13, 5: 18, 6: ''},
     'D#4': {1: '', 2: 4, 3: 8, 4: 13, 5: 18, 6: ''},
     'E4': {1: '', 2: 5, 3: 9, 4: 14, 5: 19, 6: ''},
     'Ab3': {1: '', 2: '', 3: 1, 4: 6, 5: 11, 6: 16},
     'G#3': {1: '', 2: '', 3: 1, 4: 6, 5: 11, 6: 16},
     'A3': {1: '', 2: '', 3: 2, 4: 7, 5: 12, 6: 17},
     'Bb3': {1: '', 2: '', 3: 3, 4: 8, 5: 13, 6: 18},
     'A#3': {1: '', 2: '', 3: 3, 4: 8, 5: 13, 6: 18},
     'B3': {1: '', 2: '', 3: 4, 4: 9, 5: 14, 6: 19},
     'Eb3': {1: '', 2: '', 3: '', 4: 1, 5: 6, 6: 11},
     'D#3': {1: '', 2: '', 3: '', 4: 1, 5: 6, 6: 11},
     'E3': {1: '', 2: '', 3: '', 4: 2, 5: 7, 6: 12},
     'F3': {1: '', 2: '', 3: '', 4: 3, 5: 8, 6: 13},
     'F#3': {1: '', 2: '', 3: '', 4: 4, 5: 9, 6: 14},
     'G3': {1: '', 2: '', 3: '', 4: 5, 5: 10, 6: 15},
     'Bb2': {1: '', 2: '', 3: '', 4: '', 5: 1, 6: 6},
     'A#2': {1: '', 2: '', 3: '', 4: '', 5: 1, 6: 6},
     'B2': {1: '', 2: '', 3: '', 4: '', 5: 2, 6: 7},
     'C3': {1: '', 2: '', 3: '', 4: '', 5: 3, 6: 8},
     'C#3': {1: '', 2: '', 3: '', 4: '', 5: 4, 6: 9},
     'D3': {1: '', 2: '', 3: '', 4: '', 5: 5, 6: 10},
     'F2': {1: '', 2: '', 3: '', 4: '', 5: '', 6: 1},
     'F#2': {1: '', 2: '', 3: '', 4: '', 5: '', 6: 2},
     'G2': {1: '', 2: '', 3: '', 4: '', 5: '', 6: 3},
     'Ab2': {1: '', 2: '', 3: '', 4: '', 5: '', 6: 4},
     'G#2': {1: '', 2: '', 3: '', 4: '', 5: '', 6: 4},
     'A2': {1: '', 2: '', 3: '', 4: '', 5: '', 6: 5},
     'B1': {1: '', 2: '', 3: '', 4: '', 5: '', 6: 5}}

MAX_RENDER_COLUMNS = 70

TAB_LINE_CHAR = '-'

FILLER_TEXT = """
********************************
*           NEXT TAB           *
********************************
"""

SCALE = {
    "major": [2, 2, 1, 2, 2, 2, 1],
    "jonian": [2, 2, 1, 2, 2, 2, 1],
    "dorian": [2, 1, 2, 2, 2, 1, 2],
    "phrygian": [1, 2, 2, 2, 1, 2, 2],
    "lydian": [2, 2, 2, 1, 2, 2, 1],
    "mixolydian": [2, 2, 1, 2, 2, 1, 2],
    "eolian": [2, 1, 2, 2, 1, 2, 2],
    "locrian": [1, 2, 2, 1, 2, 2, 2],
    "hexatonic": [2, 2, 2, 2, 2, 2],
    "minor": [2, 1, 2, 2, 1, 2, 2],
    "jazz_minor": [2, 1, 2, 2, 2, 2, 1],
}

==> tayuya-0.0.2-py3-none-any.whl: tayuya/constants.py <==
# Standard tuning of each string
GUITAR_STAFF: dict = {0: 'E', 1: 'A', 2: 'D', 3: 'G', 4: 'B', 5: 'E'}
UKULELE_STAFF: dict = {0: 'G', 1: 'C', 2: 'E', 3: 'A'}

# Number of strings
GUITAR_STRING = 6
UKULELE_STRING = 4

# MIDI metadata
TIME_SIGNATURE = 'time_signature'
NOTE_ON = 'note_on'
NOTE_OFF = 'note_off'
HALF_NOTE = 'half'
WHOLE_NOTE = 'whole'
QUARTER_NOTE = 'quarter'
EIGHTH_NOTE = 'eighth'
SIXTEENTH_NOTE = 'sixteenth'

# Note type to note name mappings
NUM_TO_NOTES = {1: WHOLE_NOTE, 2: HALF_NOTE, 4: QUARTER_NOTE,
                8: EIGHTH_NOTE, 16: SIXTEENTH_NOTE}

# Notes on all strings and fret of a guitar
# This is unused. Can remove
FRET_NOTES = \
    [['F4', 'F#4', 'G4', 'Ab4', 'A4', 'Bb4', 'B4', 'C5', 'C#5', 'D5', 'Eb5', 'E5', 'F5', 'F#5', 'G5', 'Ab5', 'A5', 'Bb5', 'B5', 'C6', 'C#6', 'D6'],  # E
     ['C4', 'C#4', 'D4', 'Eb4', 'E4', 'F4', 'F#4', 'G4', 'Ab4', 'A4', 'Bb4', 'B4', 'C5', 'C#5', 'D5', 'Eb5', 'E5', 'F5', 'F#5', 'G5', 'Ab5', 'A5'],  # B
     ['Ab3', 'A3', 'Bb3', 'B3', 'C4', 'C#4', 'D4', 'Eb4', 'E4', 'F4', 'F#4', 'G4', 'Ab4', 'A4', 'Bb4', 'B4', 'C5', 'C#5', 'D5', 'Eb5', 'E5', 'F5'],  # G
     ['Eb3', 'E3', 'F3', 'F#3', 'G3', 'Ab3', 'A3', 'Bb3', 'B3', 'C4', 'C#4', 'D4', 'Eb4', 'E4', 'F4', 'F#4', 'G4', 'Ab4', 'A4', 'Bb4', 'B4', 'C5'],  # D
     ['Bb2', 'B2', 'C3', 'C#3', 'D3', 'Eb3', 'E3', 'F3', 'F#3', 'G3', 'Ab3', 'A3', 'Bb3', 'B3', 'C4', 'C#4', 'D4', 'Eb4', 'E4', 'F4', 'F#4', 'G4'],  # A
     ['F2', 'F#2', 'G2', 'Ab2', 'A2', 'Bb2', 'B2', 'C3', 'C#3', 'D3', 'Eb3', 'E3', 'F3', 'F#3', 'G3', 'Ab3', 'A3', 'Bb3', 'B3', 'C4', 'C#4', 'D4']]  # E
    #                3           5            7            9                  12                 15           17           19          21

TRACK_ERROR_MESSAGE = 'No track with string instrument found'

# MIDI value to notes mapping
MIDI_TO_NOTES = {
    0: [''],
    1: [''],
    10: [''],
    100: ['E7'],
    101: ['F7'],
    102: ['F#7', 'Gb7'],
    103: ['G7'],
    104: ['G#7', 'Ab7'],
    105: ['A7'],
    106: ['A#7', 'Bb7'],
    107: ['B7'],
    108: ['C8'],
    109: ['C#8', 'Db8'],
    11: [''],
    110: ['D8'],
    111: ['D#8', 'Eb8'],
    112: ['E8'],
    113: ['F8'],
    114: ['F#8', 'Gb8'],
    115: ['G8'],
    116: ['G#8', 'Ab8'],
    117: ['A8'],
    118: ['A#8', 'Bb8'],
    119: ['B8'],
    12: [''],
    120: ['C9'],
    121: ['C#9', 'Db9'],
    122: ['D9'],
    123: ['D#9', 'Eb9'],
    124: ['E9'],
    125: ['F9'],
    126: ['F#9', 'Gb9'],
    127: ['G9'],
    13: [''],
    14: [''],
    15: [''],
    16: [''],
    17: [''],
    18: [''],
    19: [''],
    2: [''],
    20: [''],
    21: ['A0'],
    22: ['A#0', 'Bb0'],
    23: ['B0'],
    24: ['C1'],
    25: ['C#1', 'Db1'],
    26: ['D1'],
    27: ['D#1', 'Eb1'],
    28: ['E1'],
    29: ['F1'],
    3: [''],
    30: ['F#1', 'Gb1'],
    31: ['G1'],
    32: ['G#1', 'Ab1'],
    33: ['A1'],
    34: ['A#1', 'Bb1'],
    35: ['B1'],
    36: ['C2'],
    37: ['C#2', 'Db2'],
    38: ['D2'],
    39: ['D#2', 'Eb2'],
    4: [''],
    40: ['E2'],
    41: ['F2'],
    42: ['F#2', 'Gb2'],
    43: ['G2'],
    44: ['G#2', 'Ab2'],
    45: ['A2'],
    46: ['A#2', 'Bb2'],
    47: ['B2'],
    48: ['C3'],
    49: ['C#3', 'Db3'],
    5: [''],
    50: ['D3'],
    51: ['D#3', 'Eb3'],
    52: ['E3'],
    53: ['F3'],
    54: ['F#3', 'Gb3'],
    55: ['G3'],
    56: ['G#3', 'Ab3'],
    57: ['A3'],
    58: ['A#3', 'Bb3'],
    59: ['B3'],
    6: [''],
    60: ['C4'],
    61: ['C#4', 'Db4'],
    62: ['D4'],
    63: ['D#4', 'Eb4'],
    64: ['E4'],
    65: ['F4'],
    66: ['F#4', 'Gb4'],
    67: ['G4'],
    68: ['G#4', 'Ab4'],
    69: ['A4'],
    7: [''],
    70: ['A#4', 'Bb4'],
    71: ['B4'],
    72: ['C5'],
    73: ['C#5', 'Db5'],
    74: ['D5'],
    75: ['D#5', 'Eb5'],
    76: ['E5'],
    77: ['F5'],
    78: ['F#5', 'Gb5'],
    79: ['G5'],
    8: [''],
    80: ['G#5', 'Ab5'],
    81: ['A5'],
    82: ['A#5', 'Bb5'],
    83: ['B5'],
    84: ['C6'],
    85: ['C#6', 'Db6'],
    86: ['D6'],
    87: ['D#6', 'Eb6'],
    88: ['E6'],
    89: ['F6'],
    9: [''],
    90: ['F#6', 'Gb6'],
    91: ['G6'],
    92: ['G#6', 'Ab6'],
    93: ['A6'],
    94: ['A#6', 'Bb6'],
    95: ['B6'],
    96: ['C7'],
    97: ['C#7', 'Db7'],
    98: ['D7'],
    99: ['D#7', 'Eb7']
}

# Note to string and fret mappings
NOTE_TO_STRING =  \
    {'F4': {1: 1, 2: 6, 3: 10, 4: 15, 5: 20, 6: ''},
     'F#4': {1: 2, 2: 7, 3: 11, 4: 16, 5: 21, 6: ''},
     'G4': {1: 3, 2: 8, 3: 12, 4: 17, 5: 22, 6: ''},
     'Ab4': {1: 4, 2: 9, 3: 13, 4: 18, 5: '', 6: ''},
     'G#4': {1: 4, 2: 9, 3: 13, 4: 18, 5: '', 6: ''},
     'A4': {1: 5, 2: 10, 3: 14, 4: 19, 5: '', 6: ''},
     'Bb4': {1: 6, 2: 11, 3: 15, 4: 20, 5: '', 6: ''},
     'A#4': {1: 6, 2: 11, 3: 15, 4: 20, 5: '', 6: ''},
     'B4': {1: 7, 2: 12, 3: 16, 4: 21, 5: '', 6: ''},
     'C5': {1: 8, 2: 13, 3: 17, 4: 22, 5: '', 6: ''},
     'C#5': {1: 9, 2: 14, 3: 18, 4: '', 5: '', 6: ''},
     'D5': {1: 10, 2: 15, 3: 19, 4: '', 5: '', 6: ''},
     'Eb5': {1: 11, 2: 16, 3: 20, 4: '', 5: '', 6: ''},
     'D#5': {1: 11, 2: 16, 3: 20, 4: '', 5: '', 6: ''},
     'E5': {1: 12, 2: 17, 3: 21, 4: '', 5: '', 6: ''},
     'F5': {1: 13, 2: 18, 3: 22, 4: '', 5: '', 6: ''},
     'F#5': {1: 14, 2: 19, 3: '', 4: '', 5: '', 6: ''},
     'G5': {1: 15, 2: 20, 3: '', 4: '', 5: '', 6: ''},
     'Ab5': {1: 16, 2: 21, 3: '', 4: '', 5: '', 6: ''},
     'G#5': {1: 16, 2: 21, 3: '', 4: '', 5: '', 6: ''},
     'A5': {1: 17, 2: 22, 3: '', 4: '', 5: '', 6: ''},
     'Bb5': {1: 18, 2: '', 3: '', 4: '', 5: '', 6: ''},
     'A#5': {1: 18, 2: '', 3: '', 4: '', 5: '', 6: ''},
     'B5': {1: 19, 2: '', 3: '', 4: '', 5: '', 6: ''},
     'C6': {1: 20, 2: '', 3: '', 4: '', 5: '', 6: ''},
     'C#6': {1: 21, 2: '', 3: '', 4: '', 5: '', 6: ''},
     'D6': {1: 22, 2: '', 3: '', 4: '', 5: '', 6: ''},
     'C4': {1: '', 2: 1, 3: 5, 4: 10, 5: 15, 6: 20},
     'C#4': {1: '', 2: 2, 3: 6, 4: 11, 5: 16, 6: 21},
     'D4': {1: '', 2: 3, 3: 7, 4: 12, 5: 17, 6: 22},
     'Eb4': {1: '', 2: 4, 3: 8, 4: 13, 5: 18, 6: ''},
     'D#4': {1: '', 2: 4, 3: 8, 4: 13, 5: 18, 6: ''},
     'E4': {1: '', 2: 5, 3: 9, 4: 14, 5: 19, 6: ''},
     'Ab3': {1: '', 2: '', 3: 1, 4: 6, 5: 11, 6: 16},
     'G#3': {1: '', 2: '', 3: 1, 4: 6, 5: 11, 6: 16},
     'A3': {1: '', 2: '', 3: 2, 4: 7, 5: 12, 6: 17},
     'Bb3': {1: '', 2: '', 3: 3, 4: 8, 5: 13, 6: 18},
     'A#3': {1: '', 2: '', 3: 3, 4: 8, 5: 13, 6: 18},
     'B3': {1: '', 2: '', 3: 4, 4: 9, 5: 14, 6: 19},
     'Eb3': {1: '', 2: '', 3: '', 4: 1, 5: 6, 6: 11},
     'D#3': {1: '', 2: '', 3: '', 4: 1, 5: 6, 6: 11},
     'E3': {1: '', 2: '', 3: '', 4: 2, 5: 7, 6: 12},
     'F3': {1: '', 2: '', 3: '', 4: 3, 5: 8, 6: 13},
     'F#3': {1: '', 2: '', 3: '', 4: 4, 5: 9, 6: 14},
     'G3': {1: '', 2: '', 3: '', 4: 5, 5: 10, 6: 15},
     'Bb2': {1: '', 2: '', 3: '', 4: '', 5: 1, 6: 6},
     'A#2': {1: '', 2: '', 3: '', 4: '', 5: 1, 6: 6},
     'B2': {1: '', 2: '', 3: '', 4: '', 5: 2, 6: 7},
     'C3': {1: '', 2: '', 3: '', 4: '', 5: 3, 6: 8},
     'C#3': {1: '', 2: '', 3: '', 4: '', 5: 4, 6: 9},
     'D3': {1: '', 2: '', 3: '', 4: '', 5: 5, 6: 10},
     'F2': {1: '', 2: '', 3: '', 4: '', 5: '', 6: 1},
     'F#2': {1: '', 2: '', 3: '', 4: '', 5: '', 6: 2},
     'G2': {1: '', 2: '', 3: '', 4: '', 5: '', 6: 3},
     'Ab2': {1: '', 2: '', 3: '', 4: '', 5: '', 6: 4},
     'G#2': {1: '', 2: '', 3: '', 4: '', 5: '', 6: 4},
     'A2': {1: '', 2: '', 3: '', 4: '', 5: '', 6: 5},
     'B1': {1: '', 2: '', 3: '', 4: '', 5: '', 6: 5}}

# Max length of tablature in CLI mode
MAX_RENDER_COLUMNS = 70

TAB_LINE_CHAR = '-'

FILLER_TEXT = """
********************************
*           NEXT TAB           *
********************************
"""

# Common scale an steps mappings
SCALE = {
    "major": [2, 2, 1, 2, 2, 2, 1],
    "jonian": [2, 2, 1, 2, 2, 2, 1],
    "dorian": [2, 1, 2, 2, 2, 1, 2],
    "phrygian": [1, 2, 2, 2, 1, 2, 2],
    "lydian": [2, 2, 2, 1, 2, 2, 1],
    "mixolydian": [2, 2, 1, 2, 2, 1, 2],
    "eolian": [2, 1, 2, 2, 1, 2, 2],
    "locrian": [1, 2, 2, 1, 2, 2, 2],
    "hexatonic": [2, 2, 2, 2, 2, 2],
    "minor": [2, 1, 2, 2, 1, 2, 2],
    "jazz_minor": [2, 1, 2, 2, 2, 2, 1],
}
